aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/i2c/chips/eeprom.c
diff options
context:
space:
mode:
authorJean Delvare <khali@linux-fr.org>2005-07-31 21:42:02 +0200
committerGreg Kroah-Hartman <gregkh@suse.de>2005-09-05 09:14:20 -0700
commit2ed2dc3c116d26fc6a9384e83d136b15cc203b6c (patch)
treec79308b2cfe55eaddc95c47cbcafa6e0cae27413 /drivers/i2c/chips/eeprom.c
parent[PATCH] hwmon: hwmon vs i2c, second round (03/11) (diff)
downloadlinux-dev-2ed2dc3c116d26fc6a9384e83d136b15cc203b6c.tar.xz
linux-dev-2ed2dc3c116d26fc6a9384e83d136b15cc203b6c.zip
[PATCH] hwmon: hwmon vs i2c, second round (04/11)
i2c_probe and i2c_detect now do the exact same thing and operate on the same data structure, so we can have everyone call i2c_probe. Signed-off-by: Jean Delvare <khali@linux-fr.org> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/i2c/chips/eeprom.c')
-rw-r--r--drivers/i2c/chips/eeprom.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/i2c/chips/eeprom.c b/drivers/i2c/chips/eeprom.c
index 9466ada68932..befac01ecda6 100644
--- a/drivers/i2c/chips/eeprom.c
+++ b/drivers/i2c/chips/eeprom.c
@@ -152,10 +152,10 @@ static struct bin_attribute eeprom_attr = {
static int eeprom_attach_adapter(struct i2c_adapter *adapter)
{
- return i2c_detect(adapter, &addr_data, eeprom_detect);
+ return i2c_probe(adapter, &addr_data, eeprom_detect);
}
/* This function is called by i2c_detect */
int eeprom_detect(struct i2c_adapter *adapter, int address, int kind)
{
struct i2c_client *new_client;
@@ -152,10 +152,10 @@ static struct bin_attribute eeprom_attr = {
}
-/* This function is called by i2c_detect */
+/* This function is called by i2c_probe */
int eeprom_detect(struct i2c_adapter *adapter, int address, int kind)
{